# Generated by Django 4.2.6 on 2023-11-02 08:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('routing', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='solarsystemconnection',
            name='prefer_less_safe',
            field=models.FloatField(default=1, verbose_name='Weighting for Prefer Less Safe Routing'),
        ),
        migrations.AddField(
            model_name='solarsystemconnection',
            name='prefer_safest',
            field=models.FloatField(default=1, verbose_name='Weighting for Prefer Safest Routing'),
        ),
        migrations.AddField(
            model_name='solarsystemconnection',
            name='prefer_shortest',
            field=models.FloatField(default=1, verbose_name='Weighting for Prefer Shortest Routing'),
        ),
    ]
