# Generated by Django 4.2.6 on 2023-11-02 13:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('routing', '0002_solarsystemconnection_prefer_less_safe_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='TrigInvasion',
            fields=[
                ('system', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, related_name='+', serialize=False, to='routing.solarsystem', verbose_name='Solar System')),
                ('status', models.CharField(choices=[('edencom_minor_victory', 'EDENCOM Minor Victory'), ('final_liminality', 'Final Liminality'), ('fortress', 'Fortress'), ('triglavian_minor_victory', 'Triglavian Minor Victory')], max_length=50, verbose_name='Mass Remaining')),
            ],
            options={
                'verbose_name': 'Triglavian/Edencom Invasion',
                'verbose_name_plural': 'Triglavian/Edencom Invasions',
            },
        ),
    ]
