# Generated by Django 4.2.6 on 2023-11-02 07:44

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SolarSystem',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False, verbose_name='Solar System ID')),
                ('security_status', models.FloatField(validators=[django.core.validators.MinValueValidator(0.0), django.core.validators.MaxValueValidator(1.0)], verbose_name='Security Status')),
            ],
            options={
                'verbose_name': 'Solar System',
                'verbose_name_plural': 'Solar Systems',
            },
        ),
        migrations.CreateModel(
            name='SolarSystemConnection',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('fromsolarsystem', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='routing.solarsystem', verbose_name='From Solar System')),
                ('tosolarsystem', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='routing.solarsystem', verbose_name='To Solar System')),
            ],
            options={
                'verbose_name': 'Solar System Connections',
                'verbose_name_plural': 'Solar System Connection',
                'unique_together': {('fromsolarsystem', 'tosolarsystem')},
            },
        ),
    ]
